==> tikiwiki-10.2.txz: usr/local/www/tikiwiki-10.2/lang/es/language.js <==
/* 
 * Javascript translation definition
 * Example in Spanish
 * 
 * $Id: language.js 27909 2010-07-09 13:33:31Z jonnybradley $
 */

lang = {
	"Very Secure" : "Muy Segura",
	"Secure" : "Segura",
	"Very Strong" : "Muy Fuerte",
	"Strong" : "Fuerte",
	"Average" : "Intermedia",
	"Weak" : "Floja",
	"Very Weak" : "Muy Floja",
	"Strength" : "Fuerza",
	"Passwords match" : "Las contraseñas coinciden",
	"Valid Email" : "Correo-e válido",
	"Close" : "Cerrar",
	"Submit" : "Enviar",
	"Insert" : "Insertar",
	"Replace" : "Sustituir",
	"Match" : "Igual",
	"Do not match" : "Diferente",
	"Advanced options" : "Opciones avanzadas",
	"Pick a file." : "Escoge un archivo",
	"Add Field" : "Añade un campo",
	"Edit Field" : "Modifica un campo",
	"Removing the field will result in data loss. Are you sure?" : "La supresión del campo comportará la supresión de datos. ¿Estás seguro/a?",
	"Save" : "Graba",
	"Cancel" : "Cancela",
	"Delete" : "Borra",	
	"Unassign module" : "Desasigna el módulo",
	"Edit module" : "Modifica el módulo",
	"Edit module:" : "Modifica el módulo:",
	"Favorite" : "Favorito",
	"What address are you looking for?" : "¿Qué dirección estás buscando?",
	"Filter:" : "Filtro:",
	"Please enter a page name" : "Por favor, introduce un nombre de página",
	"Change Highlighter" : "Cambia el Resaltador",
	"Toggle Highlighter" : "Conmuta el Resaltador",
	"Are you sure you want to unassign this module?" : "¿Estás seguro que quieres desasignar este módulo?"
	// remember the IE does not support ending comma on last item
};

==> tikiwiki-15.0.txz: usr/local/www/tikiwiki-15.0/lang/es/language.js <==
/* 
 * Javascript translation definition
 * Example in Spanish
 * 
 * $Id: language.js 27909 2010-07-09 13:33:31Z jonnybradley $
 */

lang = {
	"Default" : "Por omisión",
	"Very Secure" : "Muy Segura",
	"Secure" : "Segura",
	"Very Strong" : "Muy Fuerte",
	"Strong" : "Fuerte",
	"Average" : "Intermedia",
	"Weak" : "Floja",
	"Very Weak" : "Muy Floja",
	"Strength" : "Fuerza",
	"Valid User Name" : "Nombre válido de persona usuaria",
	"Passwords match" : "Las contraseñas coinciden",
	"Valid Email" : "Correo-e válido",
	"Close" : "Cerrar",
	"Submit" : "Enviar",
	"Insert" : "Insertar",
	"Replace" : "Sustituir",
	"Match" : "Igual",
	"Do not match" : "Diferente",
	"Advanced options" : "Opciones avanzadas",
	"Pick a file." : "Escoge un archivo",
	"Add Field" : "Añade un campo",
	"Edit Field" : "Modifica un campo",
	"Removing the field will result in data loss. Are you sure?" : "La supresión del campo comportará la supresión de datos. ¿Estás seguro/a?",
	"Save" : "Graba",
	"Cancel" : "Cancela",
	"Delete" : "Borra",	
	"Unassign module" : "Desasigna el módulo",
	"Edit module" : "Modifica el módulo",
	"Edit module:" : "Modifica el módulo:",
	"Favorite" : "Favorito",
	"What address are you looking for?" : "¿Qué dirección estás buscando?",
	"Filter:" : "Filtro:",
	"Please enter a page name" : "Por favor, introduce un nombre de página",
	"Change Highlighter" : "Cambia el Resaltador",
	"Toggle Highlighter" : "Conmuta el Resaltador",
	"Are you sure you want to unassign this module?" : "¿Estás seguro que quieres desasignar este módulo?",
	"Search Location" : "Busca una dirección",
	"To My Location" : "Localiza mi posición",
	"StreetView is not available at this specific point on the map. Zoom in as needed and make sure to click on a blue line." : "La función StreetView no está disponible en este punto específico sobre el mapa. Aproxímate con el zoom lo que necesites y asegúrate que haces clic sobre una línea azul.",
	"Browse Files" : "Abre la lista de archivos",
	// remember the IE does not support ending comma on last item
	 "Bogus entry" : "bogus entry"
};
